@@ -29,13 +29,13 @@ class optimExModel(nn.Module):
         return x
 
 
-def run(gpu_id=-1):
+def run(gpu_id):
+    os.environ['CUDA_VISIBLE_DEVICES'] = str(gpu_id)
     dataset = torchvision.datasets.CIFAR10('./dataset', train=False, transform=torchvision.transforms.ToTensor(),
                                            download=True)
-    dataloader = DataLoader(dataset, batch_size=1)
+    dataloader = DataLoader(dataset, batch_size=64)
     loss = nn.CrossEntropyLoss()
-    if gpu_id >= 0:
-        os.environ['CUDA_VISIBLE_DEVICES'] = str(gpu_id)
+
     optim_ex = optimExModel()
     optim = torch.optim.SGD(optim_ex.parameters(), lr=0.01)
     for epoch in range(10):
@@ -52,5 +52,3 @@ def run(gpu_id=-1):
         print(loss_sum)
 
 
-if __name__ == '__main__':
-    run()
\ No newline at end of file
